# Django Haveli Admin


**Improved theme for Django admin Interface**.

Django Haveli Admin is alternative for [Django](http://www.djangoproject.com) administration interface.

# License

* Django Haveli Admin is licensed under BSD-3-Clause license.


# Docs & Support

* Documentation: https://django-haveli-admin.readthedocs.io/en/latest/


# Requirement

* Django: 2.1 or above

# Usage

**project/settings.py**

Always place the above django's default admin package (django.contrib.admin). So that it could override the existin django theme.

```
INSTALLED_APPS = [

    'django_haveli_admin',
    'django.contrib.admin',
    ...
]
```



# Sample

**Django Haveli Admin: Login**
![alt text](https://github.com/purnendukar/django-haveli-admin/blob/master/django_haveli_admin-sample/django_haveli_login.png?raw=true)

**Django Haveli Admin: Dashboard**
![alt text](https://github.com/purnendukar/django-haveli-admin/blob/master/django_haveli_admin-sample/django_haveli_dashboard.png?raw=true)

**Django Haveli Admin: Nav Sidebar**
![alt text](https://github.com/purnendukar/django-haveli-admin/blob/master/django_haveli_admin-sample/django_haveli_sidebar.png?raw=true)

**Django Haveli Admin: Filters**
![alt text](https://github.com/purnendukar/django-haveli-admin/blob/master/django_haveli_admin-sample/django_haveli_filters.png?raw=true)

**Django Haveli Admin: Change Form**
![alt text](https://github.com/purnendukar/django-haveli-admin/blob/master/django_haveli_admin-sample/django_haveli_changeform.png?raw=true)



